@@ -23,9 +23,9 @@ from ._base import NamespacedClient
 from .utils import (
     SKIP_IN_PATH,
     Stability,
+    _availability_warning,
     _quote,
     _rewrite_parameters,
-    _stability_warning,
 )
 
 
@@ -101,7 +101,7 @@ class FleetClient(NamespacedClient):
     @_rewrite_parameters(
         body_name="searches",
     )
-    @_stability_warning(Stability.EXPERIMENTAL)
+    @_availability_warning(Stability.EXPERIMENTAL)
     async def msearch(
         self,
         *,
@@ -138,8 +138,8 @@ class FleetClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Run multiple Fleet searches.
-          Run several Fleet searches with a single API request.
+          <p>Run multiple Fleet searches.</p>
+          <p>Run several Fleet searches with a single API request.
           The API follows the same structure as the multi search API.
           However, similar to the Fleet search API, it supports the <code>wait_for_checkpoints</code> parameter.</p>
 
@@ -293,7 +293,7 @@ class FleetClient(NamespacedClient):
             "from": "from_",
         },
     )
-    @_stability_warning(Stability.EXPERIMENTAL)
+    @_availability_warning(Stability.EXPERIMENTAL)
     async def search(
         self,
         *,
@@ -388,8 +388,8 @@ class FleetClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Run a Fleet search.
-          The purpose of the Fleet search API is to provide an API where the search will be run only
+          <p>Run a Fleet search.</p>
+          <p>The purpose of the Fleet search API is to provide an API where the search will be run only
           after the provided checkpoint has been processed and is visible for searches inside of Elasticsearch.</p>
 
 
@@ -642,11 +642,7 @@ class FleetClient(NamespacedClient):
                 __body["track_total_hits"] = track_total_hits
             if version is not None:
                 __body["version"] = version
-        if not __body:
-            __body = None  # type: ignore[assignment]
-        __headers = {"accept": "application/json"}
-        if __body is not None:
-            __headers["content-type"] = "application/json"
+        __headers = {"accept": "application/json", "content-type": "application/json"}
         return await self.perform_request(  # type: ignore[return-value]
             "POST",
             __path,
