@@ -39,12 +39,12 @@ class QueryRulesClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Delete a query rule.
-          Delete a query rule within a query ruleset.
+          <p>Delete a query rule.</p>
+          <p>Delete a query rule within a query ruleset.
           This is a destructive action that is only recoverable by re-adding the same rule with the create or update query rule API.</p>
 
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/delete-query-rule.html>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-query-rules-delete-rule>`_
 
         :param ruleset_id: The unique identifier of the query ruleset containing the
             rule to delete
@@ -92,12 +92,12 @@ class QueryRulesClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Delete a query ruleset.
-          Remove a query ruleset and its associated data.
+          <p>Delete a query ruleset.</p>
+          <p>Remove a query ruleset and its associated data.
           This is a destructive action that is not recoverable.</p>
 
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/delete-query-ruleset.html>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-query-rules-delete-ruleset>`_
 
         :param ruleset_id: The unique identifier of the query ruleset to delete
         """
@@ -138,11 +138,11 @@ class QueryRulesClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Get a query rule.
-          Get details about a query rule within a query ruleset.</p>
+          <p>Get a query rule.</p>
+          <p>Get details about a query rule within a query ruleset.</p>
 
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/get-query-rule.html>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-query-rules-get-rule>`_
 
         :param ruleset_id: The unique identifier of the query ruleset containing the
             rule to retrieve
@@ -190,11 +190,11 @@ class QueryRulesClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Get a query ruleset.
-          Get details about a query ruleset.</p>
+          <p>Get a query ruleset.</p>
+          <p>Get details about a query ruleset.</p>
 
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/get-query-ruleset.html>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-query-rules-get-ruleset>`_
 
         :param ruleset_id: The unique identifier of the query ruleset
         """
@@ -237,11 +237,11 @@ class QueryRulesClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Get all query rulesets.
-          Get summarized information about the query rulesets.</p>
+          <p>Get all query rulesets.</p>
+          <p>Get summarized information about the query rulesets.</p>
 
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/list-query-rulesets.html>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-query-rules-list-rulesets>`_
 
         :param from_: The offset from the first result to fetch.
         :param size: The maximum number of results to retrieve.
@@ -294,15 +294,15 @@ class QueryRulesClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Create or update a query rule.
-          Create or update a query rule within a query ruleset.</p>
+          <p>Create or update a query rule.</p>
+          <p>Create or update a query rule within a query ruleset.</p>
           <p>IMPORTANT: Due to limitations within pinned queries, you can only pin documents using ids or docs, but cannot use both in single rule.
           It is advised to use one or the other in query rulesets, to avoid errors.
           Additionally, pinned queries have a maximum limit of 100 pinned hits.
           If multiple matching rules pin more than 100 documents, only the first 100 documents are pinned in the order they are specified in the ruleset.</p>
 
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/put-query-rule.html>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-query-rules-put-rule>`_
 
         :param ruleset_id: The unique identifier of the query ruleset containing the
             rule to be created or updated.
@@ -380,8 +380,8 @@ class QueryRulesClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Create or update a query ruleset.
-          There is a limit of 100 rules per ruleset.
+          <p>Create or update a query ruleset.</p>
+          <p>There is a limit of 100 rules per ruleset.
           This limit can be increased by using the <code>xpack.applications.rules.max_rules_per_ruleset</code> cluster setting.</p>
           <p>IMPORTANT: Due to limitations within pinned queries, you can only select documents using <code>ids</code> or <code>docs</code>, but cannot use both in single rule.
           It is advised to use one or the other in query rulesets, to avoid errors.
@@ -389,7 +389,7 @@ class QueryRulesClient(NamespacedClient):
           If multiple matching rules pin more than 100 documents, only the first 100 documents are pinned in the order they are specified in the ruleset.</p>
 
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/put-query-ruleset.html>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-query-rules-put-ruleset>`_
 
         :param ruleset_id: The unique identifier of the query ruleset to be created or
             updated.
@@ -442,11 +442,11 @@ class QueryRulesClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Test a query ruleset.
-          Evaluate match criteria against a query ruleset to identify the rules that would match that criteria.</p>
+          <p>Test a query ruleset.</p>
+          <p>Evaluate match criteria against a query ruleset to identify the rules that would match that criteria.</p>
 
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/test-query-ruleset.html>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-query-rules-test>`_
 
         :param ruleset_id: The unique identifier of the query ruleset to be created or
             updated
