@@ -15,7 +15,7 @@
 #  specific language governing permissions and limitations
 #  under the License.
 
-import pytest
+import pytest_asyncio
 import sniffio
 
 import elasticsearch
@@ -23,7 +23,7 @@ import elasticsearch
 from ...utils import CA_CERTS, wipe_cluster
 
 
-@pytest.fixture(scope="function")
+@pytest_asyncio.fixture(scope="function")
 async def async_client_factory(elasticsearch_url):
     kwargs = {}
     if sniffio.current_async_library() == "trio":
@@ -42,7 +42,7 @@ async def async_client_factory(elasticsearch_url):
             await client.close()
 
 
-@pytest.fixture(scope="function")
+@pytest_asyncio.fixture(scope="function")
 def async_client(async_client_factory):
     try:
         yield async_client_factory
