@@ -15,20 +15,20 @@
 #  specific language governing permissions and limitations
 #  under the License.
 
-import asyncio
 import logging
+import time
 from datetime import datetime, timedelta, timezone
 from unittest.mock import MagicMock, call, patch
 
+import anyio
 import pytest
-import pytest_asyncio
 from elastic_transport import ApiResponseMeta, ObjectApiResponse
 
 from elasticsearch import helpers
 from elasticsearch.exceptions import ApiError
 from elasticsearch.helpers import ScanError
 
-pytestmark = [pytest.mark.asyncio]
+pytestmark = pytest.mark.anyio
 
 
 class AsyncMock(MagicMock):
@@ -92,7 +92,7 @@ class TestStreamingBulk:
     async def test_documents_data_types(self, async_client):
         async def async_gen():
             for x in range(100):
-                await asyncio.sleep(0)
+                await anyio.sleep(0)
                 yield {"answer": x, "_id": x}
 
         def sync_gen():
@@ -123,6 +123,45 @@ class TestStreamingBulk:
             "_source"
         ]
 
+    async def test_explicit_flushes(self, async_client):
+        async def async_gen():
+            yield {"answer": 2, "_id": 0}
+            yield {"answer": 1, "_id": 1}
+            yield helpers.BULK_FLUSH
+            await anyio.sleep(0.5)
+            yield {"answer": 2, "_id": 2}
+
+        timestamps = []
+        async for ok, item in helpers.async_streaming_bulk(
+            async_client, async_gen(), index="test-index", refresh=True
+        ):
+            timestamps.append(time.time())
+            assert ok
+
+        # make sure there is a pause between the writing of the 2nd and 3rd items
+        assert timestamps[2] - timestamps[1] > (timestamps[1] - timestamps[0]) * 2
+
+    async def test_timeout_flushes(self, async_client):
+        async def async_gen():
+            yield {"answer": 2, "_id": 0}
+            yield {"answer": 1, "_id": 1}
+            await anyio.sleep(0.5)
+            yield {"answer": 2, "_id": 2}
+
+        timestamps = []
+        async for ok, item in helpers.async_streaming_bulk(
+            async_client,
+            async_gen(),
+            index="test-index",
+            refresh=True,
+            flush_after_seconds=0.05,
+        ):
+            assert ok
+            timestamps.append(time.time())
+
+        # make sure there is a pause between the writing of the 2nd and 3rd items
+        assert timestamps[2] - timestamps[1] > (timestamps[1] - timestamps[0]) * 2
+
     async def test_all_errors_from_chunk_are_raised_on_failure(self, async_client):
         await async_client.indices.create(
             index="i",
@@ -491,7 +530,7 @@ class MockResponse:
         return self().__await__()
 
 
-@pytest_asyncio.fixture(scope="function")
+@pytest.fixture(scope="function")
 async def scan_teardown(async_client):
     yield
     await async_client.clear_scroll(scroll_id="_all")
@@ -542,9 +581,10 @@ class TestScan:
             bulk.append({"value": x})
         await async_client.bulk(operations=bulk, refresh=True)
 
-        with patch.object(
-            async_client, "options", return_value=async_client
-        ), patch.object(async_client, "scroll", MockScroll()):
+        with (
+            patch.object(async_client, "options", return_value=async_client),
+            patch.object(async_client, "scroll", MockScroll()),
+        ):
             data = [
                 x
                 async for x in helpers.async_scan(
@@ -558,9 +598,10 @@ class TestScan:
             assert len(data) == 3
             assert data[-1] == {"scroll_data": 42}
 
-        with patch.object(
-            async_client, "options", return_value=async_client
-        ), patch.object(async_client, "scroll", MockScroll()):
+        with (
+            patch.object(async_client, "options", return_value=async_client),
+            patch.object(async_client, "scroll", MockScroll()),
+        ):
             with pytest.raises(ScanError):
                 data = [
                     x
@@ -576,9 +617,10 @@ class TestScan:
             assert data[-1] == {"scroll_data": 42}
 
     async def test_initial_search_error(self, async_client, scan_teardown):
-        with patch.object(
-            async_client, "options", return_value=async_client
-        ), patch.object(async_client, "clear_scroll", new_callable=AsyncMock):
+        with (
+            patch.object(async_client, "options", return_value=async_client),
+            patch.object(async_client, "clear_scroll", new_callable=AsyncMock),
+        ):
             with patch.object(
                 async_client,
                 "search",
@@ -634,15 +676,16 @@ class TestScan:
                         assert mock_scroll.calls == []
 
     async def test_no_scroll_id_fast_route(self, async_client, scan_teardown):
-        with patch.object(
-            async_client, "options", return_value=async_client
-        ), patch.object(async_client, "scroll") as scroll_mock, patch.object(
-            async_client,
-            "search",
-            MockResponse(ObjectApiResponse(body={"no": "_scroll_id"}, meta=None)),
-        ), patch.object(
-            async_client, "clear_scroll"
-        ) as clear_mock:
+        with (
+            patch.object(async_client, "options", return_value=async_client),
+            patch.object(async_client, "scroll") as scroll_mock,
+            patch.object(
+                async_client,
+                "search",
+                MockResponse(ObjectApiResponse(body={"no": "_scroll_id"}, meta=None)),
+            ),
+            patch.object(async_client, "clear_scroll") as clear_mock,
+        ):
             data = [
                 x async for x in helpers.async_scan(async_client, index="test_index")
             ]
@@ -661,9 +704,10 @@ class TestScan:
             bulk.append({"value": x})
         await async_client.bulk(operations=bulk, refresh=True)
 
-        with patch.object(
-            async_client, "options", return_value=async_client
-        ), patch.object(async_client, "scroll", MockScroll()):
+        with (
+            patch.object(async_client, "options", return_value=async_client),
+            patch.object(async_client, "scroll", MockScroll()),
+        ):
             _ = [
                 x
                 async for x in helpers.async_scan(
@@ -680,9 +724,10 @@ class TestScan:
         ]
 
         caplog.clear()
-        with patch.object(
-            async_client, "options", return_value=async_client
-        ), patch.object(async_client, "scroll", MockScroll()):
+        with (
+            patch.object(async_client, "options", return_value=async_client),
+            patch.object(async_client, "scroll", MockScroll()),
+        ):
             with pytest.raises(ScanError):
                 _ = [
                     x
@@ -706,11 +751,12 @@ class TestScan:
             bulk.append({"value": x})
         await async_client.bulk(operations=bulk, refresh=True)
 
-        with patch.object(
-            async_client, "options", return_value=async_client
-        ), patch.object(
-            async_client, "clear_scroll", wraps=async_client.clear_scroll
-        ) as spy:
+        with (
+            patch.object(async_client, "options", return_value=async_client),
+            patch.object(
+                async_client, "clear_scroll", wraps=async_client.clear_scroll
+            ) as spy,
+        ):
             _ = [
                 x
                 async for x in helpers.async_scan(
@@ -748,20 +794,21 @@ class TestScan:
     async def test_scan_auth_kwargs_forwarded(
         self, async_client, scan_teardown, kwargs
     ):
-        with patch.object(
-            async_client, "options", return_value=async_client
-        ) as options, patch.object(
-            async_client,
-            "search",
-            return_value=MockResponse(
-                ObjectApiResponse(
-                    body={
-                        "_scroll_id": "scroll_id",
-                        "_shards": {"successful": 5, "total": 5, "skipped": 0},
-                        "hits": {"hits": [{"search_data": 1}]},
-                    },
-                    meta=None,
-                )
+        with (
+            patch.object(async_client, "options", return_value=async_client) as options,
+            patch.object(
+                async_client,
+                "search",
+                return_value=MockResponse(
+                    ObjectApiResponse(
+                        body={
+                            "_scroll_id": "scroll_id",
+                            "_shards": {"successful": 5, "total": 5, "skipped": 0},
+                            "hits": {"hits": [{"search_data": 1}]},
+                        },
+                        meta=None,
+                    )
+                ),
             ),
         ):
             with patch.object(
@@ -801,20 +848,21 @@ class TestScan:
     async def test_scan_auth_kwargs_favor_scroll_kwargs_option(
         self, async_client, scan_teardown
     ):
-        with patch.object(
-            async_client, "options", return_value=async_client
-        ) as options, patch.object(
-            async_client,
-            "search",
-            return_value=MockResponse(
-                ObjectApiResponse(
-                    body={
-                        "_scroll_id": "scroll_id",
-                        "_shards": {"successful": 5, "total": 5, "skipped": 0},
-                        "hits": {"hits": [{"search_data": 1}]},
-                    },
-                    meta=None,
-                )
+        with (
+            patch.object(async_client, "options", return_value=async_client) as options,
+            patch.object(
+                async_client,
+                "search",
+                return_value=MockResponse(
+                    ObjectApiResponse(
+                        body={
+                            "_scroll_id": "scroll_id",
+                            "_shards": {"successful": 5, "total": 5, "skipped": 0},
+                            "hits": {"hits": [{"search_data": 1}]},
+                        },
+                        meta=None,
+                    )
+                ),
             ),
         ):
             with patch.object(
@@ -878,21 +926,23 @@ class TestScan:
     ],
 )
 async def test_scan_from_keyword_is_aliased(async_client, scan_kwargs):
-    with patch.object(async_client, "options", return_value=async_client), patch.object(
-        async_client,
-        "search",
-        return_value=MockResponse(
-            ObjectApiResponse(
-                body={
-                    "_scroll_id": "dummy_id",
-                    "_shards": {"successful": 5, "total": 5},
-                    "hits": {"hits": []},
-                },
-                meta=None,
-            )
-        ),
-    ) as search_mock, patch.object(
-        async_client, "clear_scroll", return_value=MockResponse(None)
+    with (
+        patch.object(async_client, "options", return_value=async_client),
+        patch.object(
+            async_client,
+            "search",
+            return_value=MockResponse(
+                ObjectApiResponse(
+                    body={
+                        "_scroll_id": "dummy_id",
+                        "_shards": {"successful": 5, "total": 5},
+                        "hits": {"hits": []},
+                    },
+                    meta=None,
+                )
+            ),
+        ) as search_mock,
+        patch.object(async_client, "clear_scroll", return_value=MockResponse(None)),
     ):
         [
             x
@@ -904,7 +954,7 @@ async def test_scan_from_keyword_is_aliased(async_client, scan_kwargs):
         assert "from" not in search_mock.call_args[1]
 
 
-@pytest_asyncio.fixture(scope="function")
+@pytest.fixture(scope="function")
 async def reindex_setup(async_client):
     bulk = []
     for x in range(100):
@@ -982,7 +1032,7 @@ class TestReindex:
         )["_source"]
 
 
-@pytest_asyncio.fixture(scope="function")
+@pytest.fixture(scope="function")
 async def parent_reindex_setup(async_client):
     body = {
         "settings": {"number_of_shards": 1, "number_of_replicas": 0},
@@ -1043,7 +1093,7 @@ class TestParentChildReindex:
         } == q
 
 
-@pytest_asyncio.fixture(scope="function")
+@pytest.fixture(scope="function")
 async def reindex_data_stream_setup(async_client):
     dt = datetime.now(tz=timezone.utc)
     bulk = []
