@@ -16,6 +16,7 @@
 #  under the License.
 
 import json
+import time
 from datetime import datetime, timedelta
 from unittest.mock import call, patch
 
@@ -75,6 +76,47 @@ def test_bulk_all_documents_get_inserted(sync_client):
     assert {"answer": 42} == sync_client.get(index="test-index", id=42)["_source"]
 
 
+def test_explicit_flushes(sync_client):
+    def sync_gen():
+        yield {"answer": 0, "_id": 0}
+        yield {"answer": 1, "_id": 1}
+        yield helpers.BULK_FLUSH
+        time.sleep(0.5)
+        yield {"answer": 2, "_id": 2}
+
+    timestamps = []
+    for ok, item in helpers.streaming_bulk(
+        sync_client, sync_gen(), index="test-index", refresh=True
+    ):
+        assert ok
+        timestamps.append(time.time())
+
+    # make sure there is a pause between the writing of the 2nd and 3rd items
+    assert timestamps[2] - timestamps[1] > (timestamps[1] - timestamps[0]) * 2
+
+
+def test_timeout_flushes(sync_client):
+    def sync_gen():
+        yield {"answer": 0, "_id": 0}
+        yield {"answer": 1, "_id": 1}
+        time.sleep(0.5)
+        yield {"answer": 2, "_id": 2}
+
+    timestamps = []
+    for ok, item in helpers.streaming_bulk(
+        sync_client,
+        sync_gen(),
+        index="test-index",
+        refresh=True,
+        flush_after_seconds=0.05,
+    ):
+        assert ok
+        timestamps.append(time.time())
+
+    # make sure there is a pause between the writing of the 2nd and 3rd items
+    assert timestamps[2] - timestamps[1] > (timestamps[1] - timestamps[0]) * 2
+
+
 def test_bulk_all_errors_from_chunk_are_raised_on_failure(sync_client):
     sync_client.indices.create(
         index="i",
