@@ -25,6 +25,7 @@ import io
 import json
 import os
 import re
+import subprocess
 import warnings
 import zipfile
 from typing import Tuple, Union
@@ -35,6 +36,7 @@ import yaml
 
 from elasticsearch import ApiError, ElasticsearchWarning, RequestError
 from elasticsearch._sync.client.utils import _base64_auth_header
+from elasticsearch._version import __versionstr__
 from elasticsearch.compat import string_types
 
 # some params had to be changed in python, keep track of them so we can rename
@@ -409,16 +411,21 @@ class YamlRunner:
         return value
 
     def _lookup(self, path):
-        # fetch the possibly nested value from last_response
-        value = self.last_response
         if path == "$body":
-            return value
+            return self.last_response
+        if path.startswith("$"):
+            value = None
+        else:
+            value = self.last_response
         path = path.replace(r"\.", "\1")
         for step in path.split("."):
             if not step:
                 continue
             # We check body again to handle E.g. '$body.$backing_index.data_stream'
-            if step.startswith("$body"):
+            if step == "$body":
+                assert value is None
+                # fetch the possibly nested value from last_response
+                value = self.last_response
                 continue
             step = step.replace("\1", ".")
             step = self._resolve(step)
@@ -430,11 +437,15 @@ class YamlRunner:
                 step = int(step)
                 assert isinstance(value, list)
                 assert len(value) > step
+                value = value[step]
             elif step == "_arbitrary_key_":
                 return list(value.keys())[0]
-            else:
+            elif isinstance(step, string_types) and isinstance(value, dict):
                 assert step in value
-            value = value[step]
+                value = value[step]
+            else:
+                assert value is None
+                value = step
         return value
 
     def _feature_enabled(self, name):
@@ -499,12 +510,29 @@ try:
     # Construct the HTTP and Elasticsearch client
     http = urllib3.PoolManager(retries=urllib3.Retry(total=10))
 
-    yaml_tests_url = (
-        "https://api.github.com/repos/elastic/elasticsearch-clients-tests/zipball/main"
-    )
+    branch_candidates = []
+    if "ES_YAML_TESTS_BRANCH" in os.environ and os.environ["ES_YAML_TESTS_BRANCH"]:
+        branch_candidates.append(os.environ["ES_YAML_TESTS_BRANCH"])
+    git_branch = subprocess.getoutput("git branch --show-current")
+    if git_branch and git_branch not in branch_candidates:
+        branch_candidates.append(git_branch)
+    package_version = __versionstr__.rsplit(".", 1)[0]
+    if package_version and package_version not in branch_candidates:
+        branch_candidates.append(package_version)
+    if "main" not in branch_candidates:
+        branch_candidates.append("main")
+
+    response = None
+    branch = "main"
+    for branch in branch_candidates:
+        yaml_tests_url = f"https://api.github.com/repos/elastic/elasticsearch-clients-tests/zipball/{branch}"
+        response = http.request("GET", yaml_tests_url)
+        if response.status != 404:
+            break
+    assert response is not None
 
     # Download the zip and start reading YAML from the files in memory
-    package_zip = zipfile.ZipFile(io.BytesIO(http.request("GET", yaml_tests_url).data))
+    package_zip = zipfile.ZipFile(io.BytesIO(response.data))
 
     for yaml_file in package_zip.namelist():
         if not re.match(r"^.*\/tests\/.*\.ya?ml$", yaml_file):
@@ -562,7 +590,9 @@ try:
             elif pytest_test_name in SKIPPED_TESTS or pytest_param_id in SKIPPED_TESTS:
                 pytest_param["skip"] = True
 
-            YAML_TEST_SPECS.append(pytest.param(pytest_param, id=pytest_param_id))
+            YAML_TEST_SPECS.append(
+                pytest.param(pytest_param, id=f"[{branch}]{pytest_param_id}")
+            )
 
 except Exception as e:
     warnings.warn(f"Could not load REST API tests: {str(e)}")
